<?php
// Database connection
$conn = new mysqli("localhost:3306", "dotbteam_aqua", "Stormtrooper@07", "dotbteam_aquaclock");

if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get role name and permissions
    $role_name = $_POST['role_name'];
    $permissions = isset($_POST['permissions']) ? json_encode($_POST['permissions']) : '[]';

    // Insert the new role into the database
    $stmt = $conn->prepare("INSERT INTO roles (role_name, permissions) VALUES (?, ?)");
    $stmt->bind_param("ss", $role_name, $permissions);
    $stmt->execute();

    if ($stmt->affected_rows > 0) {
        $success_message = "Role created successfully!";
    } else {
        $error_message = "An error occurred while creating the role.";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Create Role</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
</head>
<body>
    <div class="container mt-4">
        <h2>Create a New Role</h2>

        <!-- Success or Error Message -->
        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success_message) ?></div>
        <?php elseif (isset($error_message)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error_message) ?></div>
        <?php endif; ?>

        <form method="POST">
            <!-- Role Name -->
            <div class="form-group">
                <label for="role_name">Role Name</label>
                <input type="text" class="form-control" id="role_name" name="role_name" required>
            </div>

            <!-- Permissions -->
            <h4>Permissions</h4>
            <div class="row">
                <?php
                $permissions = [
                    "clock_in", "clock_out", "manage_clockin", "manage_users", "create_users", "delete_users",
                    "edit_users", "reports", "config", "manage_roles", "create_roles", "delete_roles", "edit_roles",
                    "manage_company", "edit_clockin", "delete_clockin", "create_clockin"
                ];
                
                $chunks = array_chunk($permissions, 5); // Split into 3 columns

                foreach ($chunks as $chunk):
                ?>
                    <div class="col-md-4">
                        <?php foreach ($chunk as $permission): ?>
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" id="permission_<?= $permission ?>" name="permissions[]" value="<?= $permission ?>">
                                <label class="form-check-label" for="permission_<?= $permission ?>"><?= ucfirst(str_replace('_', ' ', $permission)) ?></label>
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endforeach; ?>
            </div>

            <button type="submit" class="btn btn-primary mt-4">Create Role</button>
        </form>

        <div class="mt-4">
            <a href="manage_roles.php" class="btn btn-secondary">Back to Manage Roles</a>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.2/dist/js/bootstrap.min.js"></script>
</body>
</html>

<?php
$conn->close();
?>
