<?php
// Database connection
$host = 'localhost:3306';       // Database host
$dbname = 'dotbteam_aquaclock';     // Database name
$username = 'dotbteam_aqua';        // Your database username
$password = 'Stormtrooper@07'; 

// Create connection
$conn = new mysqli($host, $username, $password, $dbname);

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Start session
session_start();

if (!isset($_SESSION['username'])) {
    header("Location: login.php"); // Redirect to login if not logged in
    exit();
}

$username = $_SESSION['username'];
$permissions = $_SESSION['permissions']; // User permissions stored in session
$message = "";
$alertClass = "";

// Retrieve the first name of the user
$stmt = $conn->prepare("SELECT FirstName FROM users WHERE username = ?");
$stmt->bind_param("s", $username);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $firstName = $user['FirstName'];
} else {
    $firstName = "User"; // Default fallback
}
$stmt->close();

// Handle clock in/out button click
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    date_default_timezone_set('Australia/Sydney'); // Set timezone to AEST
    $currentDate = date('Y-m-d');
    $currentTime = date('H:i:s');

    // Check the last punch status
    $stmt = $conn->prepare("SELECT id, time_in, time_out FROM punches WHERE username = ? AND date = ? ORDER BY id DESC LIMIT 1");
    $stmt->bind_param("ss", $username, $currentDate);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $lastPunch = $result->fetch_assoc();

        // If last punch is a clock-in without clock-out, clock out
        if (is_null($lastPunch['time_out'])) {
            $updateStmt = $conn->prepare("UPDATE punches SET time_out = ? WHERE id = ?");
            $updateStmt->bind_param("si", $currentTime, $lastPunch['id']);
            $updateStmt->execute();
            $updateStmt->close();

            $message = "Clocked out at $currentTime";
            $alertClass = "alert-danger";
        } else {
            // Otherwise, create a new clock-in record
            $insertStmt = $conn->prepare("INSERT INTO punches (username, date, time_in) VALUES (?, ?, ?)");
            $insertStmt->bind_param("sss", $username, $currentDate, $currentTime);
            $insertStmt->execute();
            $insertStmt->close();

            $message = "Clocked in at $currentTime";
            $alertClass = "alert-success";
        }
    } else {
        // No punches for the day, create a new clock-in record
        $insertStmt = $conn->prepare("INSERT INTO punches (username, date, time_in) VALUES (?, ?, ?)");
        $insertStmt->bind_param("sss", $username, $currentDate, $currentTime);
        $insertStmt->execute();
        $insertStmt->close();

        $message = "Clocked in at $currentTime";
        $alertClass = "alert-success";
    }
    $stmt->close();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-light bg-light">
        <div class="container-fluid">
            <a class="navbar-brand" href="#">AquaClock</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item"><a class="nav-link" href="clockins.php">Clockins</a></li>
                    <?php if (in_array('reports', $permissions)): ?>
                        <li class="nav-item"><a class="nav-link" href="reports.php">Reports</a></li>
                    <?php endif; ?>
                    <?php if (in_array('manage_company', $permissions)): ?>
                        <li class="nav-item"><a class="nav-link" href="manage_company.php">Manage Company</a></li>
                    <?php endif; ?>
                    <li class="nav-item"><a class="nav-link" href="account.php">Account</a></li>
                </ul>
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item">
                        <a class="nav-link text-danger" href="logout.php">Logout</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <!-- Main Content -->
    <div class="container text-center mt-5">
        <h1>Welcome, <?php echo htmlspecialchars($firstName); ?>!</h1>
        <form method="POST" action="">
            <button type="submit" class="btn btn-primary btn-lg mt-4">Clock In/Out</button>
        </form>
        <?php if ($message): ?>
            <div class="alert <?php echo $alertClass; ?> mt-4">
                <?php echo $message; ?>
            </div>
        <?php endif; ?>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
