<?php
// Database connection
$conn = new mysqli("localhost:3306", "dotbteam_aqua", "Stormtrooper@07", "dotbteam_aquaclock");

if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Handle clock-in deletion
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_clockin'])) {
    $id = $_POST['id'];

    // Delete the clock-in record
    $query = "DELETE FROM punches WHERE id = ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $id);
    if ($stmt->execute()) {
        $success_message = "Clock-in deleted successfully!";
    } else {
        $error_message = "An error occurred while deleting the clock-in.";
    }
}

// Fetch all clock-ins in descending order by date
$clockinsQuery = "SELECT * FROM punches ORDER BY date DESC";
$clockinsResult = $conn->query($clockinsQuery);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Delete Clock-In</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
</head>
<body>
    <div class="container mt-4">
        <h2>Clock-Ins</h2>

        <!-- Success or Error Message -->
        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success_message) ?></div>
        <?php elseif (isset($error_message)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error_message) ?></div>
        <?php endif; ?>

        <!-- Table of Clock-Ins -->
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Username</th>
                    <th>Date</th>
                    <th>Time In</th>
                    <th>Time Out</th>
                    <th>Action</th>
                </tr>
            </thead>
            <tbody>
                <?php while ($row = $clockinsResult->fetch_assoc()): ?>
                    <tr>
                        <td><?= htmlspecialchars($row['id']) ?></td>
                        <td><?= htmlspecialchars($row['username']) ?></td>
                        <td><?= htmlspecialchars($row['date']) ?></td>
                        <td><?= htmlspecialchars($row['time_in']) ?></td>
                        <td><?= htmlspecialchars($row['time_out']) ?></td>
                        <td>
                            <button 
                                class="btn btn-danger btn-sm deleteClockinButton" 
                                data-id="<?= $row['id'] ?>" 
                                data-username="<?= htmlspecialchars($row['username']) ?>" 
                                data-date="<?= $row['date'] ?>"
                            >
                                Delete
                            </button>
                        </td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>

        <!-- Back Button -->
        <div>
            <a href="manage_company.php" class="btn btn-secondary">Back to Manage Company</a>
        </div>
    </div>

    <!-- Delete Confirmation Popup -->
    <div class="modal" tabindex="-1" role="dialog" id="deleteClockinModal">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Confirm Deletion</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <form method="POST">
                    <div class="modal-body">
                        <p>Are you sure you want to delete this clock-in?</p>
                        <input type="hidden" name="id" id="deleteClockinId">
                        <p id="deleteClockinDetails"></p>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancel</button>
                        <button type="submit" name="delete_clockin" class="btn btn-danger">Delete</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- JavaScript for Modal -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.2/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            // Open modal and populate fields for deletion
            $('.deleteClockinButton').click(function() {
                const id = $(this).data('id');
                const username = $(this).data('username');
                const date = $(this).data('date');

                $('#deleteClockinId').val(id);
                $('#deleteClockinDetails').text(`Username: ${username}, Date: ${date}`);

                $('#deleteClockinModal').modal('show');
            });
        });
    </script>
</body>
</html>

<?php
$conn->close();
?>
