<?php
// Database connection
$conn = new mysqli("localhost:3306", "dotbteam_aqua", "Stormtrooper@07", "dotbteam_aquaclock");

if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Handle clock-in update submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_clockin'])) {
    $id = $_POST['id'];
    $username = $_POST['username'];
    $date = $_POST['date'];
    $time_in = $_POST['time_in'];
    $time_out = $_POST['time_out'];

    // Update the clock-in record
    $query = "UPDATE punches SET username = ?, date = ?, time_in = ?, time_out = ? WHERE id = ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("ssssi", $username, $date, $time_in, $time_out, $id);
    if ($stmt->execute()) {
        $success_message = "Clock-in updated successfully!";
    } else {
        $error_message = "An error occurred while updating the clock-in.";
    }
}

// Fetch all clock-ins in descending order by date
$clockinsQuery = "SELECT * FROM punches ORDER BY date DESC";
$clockinsResult = $conn->query($clockinsQuery);

// Fetch all users for the dropdown
$usersQuery = "SELECT username FROM users";
$usersResult = $conn->query($usersQuery);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Clock-In</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
</head>
<body>
    <div class="container mt-4">
        <h2>Clock-Ins</h2>

        <!-- Success or Error Message -->
        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success_message) ?></div>
        <?php elseif (isset($error_message)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error_message) ?></div>
        <?php endif; ?>

        <!-- Table of Clock-Ins -->
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Username</th>
                    <th>Date</th>
                    <th>Time In</th>
                    <th>Time Out</th>
                    <th>Action</th>
                </tr>
            </thead>
            <tbody>
                <?php while ($row = $clockinsResult->fetch_assoc()): ?>
                    <tr>
                        <td><?= htmlspecialchars($row['id']) ?></td>
                        <td><?= htmlspecialchars($row['username']) ?></td>
                        <td><?= htmlspecialchars($row['date']) ?></td>
                        <td><?= htmlspecialchars($row['time_in']) ?></td>
                        <td><?= htmlspecialchars($row['time_out']) ?></td>
                        <td>
                            <button 
                                class="btn btn-primary btn-sm editClockinButton" 
                                data-id="<?= $row['id'] ?>" 
                                data-username="<?= htmlspecialchars($row['username']) ?>" 
                                data-date="<?= $row['date'] ?>" 
                                data-timein="<?= $row['time_in'] ?>" 
                                data-timeout="<?= $row['time_out'] ?>"
                            >
                                Edit
                            </button>
                        </td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>

        <!-- Back Button -->
        <div>
            <a href="manage_company.php" class="btn btn-secondary">Back to Manage Company</a>
        </div>
    </div>

    <!-- Edit Clock-In Popup -->
    <div class="modal" tabindex="-1" role="dialog" id="clockInModal">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Edit Clock-In</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <form method="POST">
                    <div class="modal-body">
                        <input type="hidden" name="id" id="clockinId">
                        <div class="form-group">
                            <label for="username">Username</label>
                            <select class="form-control" id="username" name="username" required>
                                <option value="">Select a user</option>
                                <?php 
                                // Fetch all users again for the dropdown
                                $usersResult->data_seek(0);
                                while ($user = $usersResult->fetch_assoc()): ?>
                                    <option value="<?= htmlspecialchars($user['username']) ?>"><?= htmlspecialchars($user['username']) ?></option>
                                <?php endwhile; ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="date">Date</label>
                            <input type="date" class="form-control" id="date" name="date" required>
                        </div>
                        <div class="form-group">
                            <label for="time_in">Time In</label>
                            <input type="time" class="form-control" id="time_in" name="time_in" required>
                        </div>
                        <div class="form-group">
                            <label for="time_out">Time Out</label>
                            <input type="time" class="form-control" id="time_out" name="time_out" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancel</button>
                        <button type="submit" name="update_clockin" class="btn btn-success">Save Changes</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- JavaScript for Modal -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.2/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            // Open modal and populate fields
            $('.editClockinButton').click(function() {
                const id = $(this).data('id');
                const username = $(this).data('username');
                const date = $(this).data('date');
                const timeIn = $(this).data('timein');
                const timeOut = $(this).data('timeout');

                $('#clockinId').val(id);
                $('#username').val(username);
                $('#date').val(date);
                $('#time_in').val(timeIn);
                $('#time_out').val(timeOut);

                $('#clockInModal').modal('show');
            });
        });
    </script>
</body>
</html>

<?php
$conn->close();
?>
