<?php
// Database connection
$conn = new mysqli("localhost:3306", "dotbteam_aqua", "Stormtrooper@07", "dotbteam_aquaclock");

if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Fetch the available roles
$rolesQuery = "SELECT id, role_name FROM roles";
$rolesResult = $conn->query($rolesQuery);

// If editing a role
if (isset($_GET['role_id'])) {
    $role_id = $_GET['role_id'];

    // Fetch the selected role details
    $roleQuery = "SELECT role_name, permissions FROM roles WHERE id = ?";
    $stmt = $conn->prepare($roleQuery);
    $stmt->bind_param("i", $role_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $role = $result->fetch_assoc();

    // Decode the JSON permissions to an array
    $currentPermissions = json_decode($role['permissions'], true);
}

// Handle the form submission to update the role
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $role_name = $_POST['role_name'];
    $permissions = isset($_POST['permissions']) ? json_encode($_POST['permissions']) : '[]';

    // Update the role in the database
    $updateQuery = "UPDATE roles SET role_name = ?, permissions = ? WHERE id = ?";
    $stmt = $conn->prepare($updateQuery);
    $stmt->bind_param("ssi", $role_name, $permissions, $role_id);
    $stmt->execute();

    if ($stmt->affected_rows > 0) {
        $success_message = "Role updated successfully!";
    } else {
        $error_message = "An error occurred while updating the role.";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Role</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
</head>
<body>
    <div class="container mt-4">
        <h2>Edit Role</h2>

        <!-- Success or Error Message -->
        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success_message) ?></div>
        <?php elseif (isset($error_message)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error_message) ?></div>
        <?php endif; ?>

        <!-- Select Role to Edit -->
        <form method="GET" class="mb-4">
            <div class="form-group">
                <label for="role_id">Select Role</label>
                <select class="form-control" id="role_id" name="role_id" required>
                    <option value="">Select Role</option>
                    <?php while ($row = $rolesResult->fetch_assoc()): ?>
                        <option value="<?= $row['id'] ?>" <?= isset($role_id) && $role_id == $row['id'] ? 'selected' : '' ?>><?= $row['role_name'] ?></option>
                    <?php endwhile; ?>
                </select>
            </div>
            <button type="submit" class="btn btn-primary">Edit Role</button>
        </form>

        <?php if (isset($role_id)): ?>
            <!-- Edit Role Form -->
            <form method="POST">
                <div class="form-group">
                    <label for="role_name">Role Name</label>
                    <input type="text" class="form-control" id="role_name" name="role_name" value="<?= htmlspecialchars($role['role_name']) ?>" required>
                </div>

                <!-- Permissions -->
                <h4>Permissions</h4>
                <div class="row">
                    <?php
                    $permissions = [
                        "clock_in", "clock_out", "manage_clockin", "manage_users", "create_users", "delete_users",
                        "edit_users", "reports", "config", "manage_roles", "create_roles", "delete_roles", "edit_roles",
                        "manage_company", "edit_clockin", "delete_clockin", "create_clockin"
                    ];
                    
                    $chunks = array_chunk($permissions, 5); // Split into 3 columns

                    foreach ($chunks as $chunk):
                    ?>
                        <div class="col-md-4">
                            <?php foreach ($chunk as $permission): ?>
                                <div class="form-check">
                                    <input type="checkbox" class="form-check-input" id="permission_<?= $permission ?>" name="permissions[]" value="<?= $permission ?>" <?= in_array($permission, $currentPermissions) ? 'checked' : '' ?>>
                                    <label class="form-check-label" for="permission_<?= $permission ?>"><?= ucfirst(str_replace('_', ' ', $permission)) ?></label>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    <?php endforeach; ?>
                </div>

                <button type="submit" class="btn btn-primary mt-4">Update Role</button>
            </form>
        <?php endif; ?>

        <div class="mt-4">
            <a href="manage_roles.php" class="btn btn-secondary">Back to Manage Roles</a>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.2/dist/js/bootstrap.min.js"></script>
</body>
</html>

<?php
$conn->close();
?>
