<?php
// Database connection
$conn = new mysqli("localhost:3306", "dotbteam_aqua", "Stormtrooper@07", "dotbteam_aquaclock");

if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Handle user update
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_user'])) {
    $id = $_POST['id'];
    $firstName = $_POST['first_name'];
    $lastName = $_POST['last_name'];
    $email = $_POST['email'];
    $phone = $_POST['phone'];
    $address = $_POST['address'];
    $username = $_POST['username'];
    $password = password_hash($_POST['password'], PASSWORD_DEFAULT);
    $roleId = $_POST['role_id'];

    $query = "UPDATE users SET FirstName = ?, last_name = ?, email = ?, phone = ?, address = ?, username = ?, password = ?, role_id = ? WHERE id = ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("sssssssii", $firstName, $lastName, $email, $phone, $address, $username, $password, $roleId, $id);

    if ($stmt->execute()) {
        $success_message = "User updated successfully!";
    } else {
        $error_message = "An error occurred while updating the user.";
    }
}

// Fetch all users
$usersQuery = "SELECT u.id, u.FirstName, u.last_name, u.email, u.phone, u.address, u.username, u.role_id, r.role_name 
               FROM users u 
               LEFT JOIN roles r ON u.role_id = r.id 
               ORDER BY u.id ASC";
$usersResult = $conn->query($usersQuery);

// Fetch roles for the dropdown
$rolesQuery = "SELECT * FROM roles";
$rolesResult = $conn->query($rolesQuery);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit User</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
</head>
<body>
    <div class="container mt-4">
        <h2>Edit Users</h2>

        <!-- Success or Error Message -->
        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success_message) ?></div>
        <?php elseif (isset($error_message)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error_message) ?></div>
        <?php endif; ?>

        <!-- Table of Users -->
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>First Name</th>
                    <th>Last Name</th>
                    <th>Email</th>
                    <th>Phone</th>
                    <th>Username</th>
                    <th>Role</th>
                    <th>Action</th>
                </tr>
            </thead>
            <tbody>
                <?php while ($row = $usersResult->fetch_assoc()): ?>
                    <tr>
                        <td><?= htmlspecialchars($row['id']) ?></td>
                        <td><?= htmlspecialchars($row['FirstName']) ?></td>
                        <td><?= htmlspecialchars($row['last_name']) ?></td>
                        <td><?= htmlspecialchars($row['email']) ?></td>
                        <td><?= htmlspecialchars($row['phone']) ?></td>
                        <td><?= htmlspecialchars($row['username']) ?></td>
                        <td><?= htmlspecialchars($row['role_name']) ?></td>
                        <td>
                            <button 
                                class="btn btn-primary btn-sm editUserButton" 
                                data-id="<?= $row['id'] ?>" 
                                data-first-name="<?= htmlspecialchars($row['FirstName']) ?>" 
                                data-last-name="<?= htmlspecialchars($row['last_name']) ?>" 
                                data-email="<?= htmlspecialchars($row['email']) ?>" 
                                data-phone="<?= htmlspecialchars($row['phone']) ?>" 
                                data-address="<?= htmlspecialchars($row['address']) ?>" 
                                data-username="<?= htmlspecialchars($row['username']) ?>" 
                                data-role-id="<?= $row['role_id'] ?>"
                            >
                                Edit
                            </button>
                        </td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>

        <!-- Back Button -->
        <div>
            <a href="manage_company.php" class="btn btn-secondary">Back to Manage Company</a>
        </div>
    </div>

    <!-- Edit User Popup -->
    <div class="modal" tabindex="-1" role="dialog" id="editUserModal">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Edit User</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <form method="POST">
                    <div class="modal-body">
                        <input type="hidden" name="id" id="editUserId">
                        <div class="form-group">
                            <label for="editFirstName">First Name</label>
                            <input type="text" class="form-control" id="editFirstName" name="first_name" required>
                        </div>
                        <div class="form-group">
                            <label for="editLastName">Last Name</label>
                            <input type="text" class="form-control" id="editLastName" name="last_name" required>
                        </div>
                        <div class="form-group">
                            <label for="editEmail">Email</label>
                            <input type="email" class="form-control" id="editEmail" name="email" required>
                        </div>
                        <div class="form-group">
                            <label for="editPhone">Phone</label>
                            <input type="text" class="form-control" id="editPhone" name="phone">
                        </div>
                        <div class="form-group">
                            <label for="editAddress">Address</label>
                            <input type="text" class="form-control" id="editAddress" name="address">
                        </div>
                        <div class="form-group">
                            <label for="editUsername">Username</label>
                            <input type="text" class="form-control" id="editUsername" name="username" required>
                        </div>
                        <div class="form-group">
                            <label for="editPassword">Password</label>
                            <input type="password" class="form-control" id="editPassword" name="password">
                        </div>
                        <div class="form-group">
                            <label for="editRoleId">Role</label>
                            <select class="form-control" id="editRoleId" name="role_id" required>
                                <?php while ($role = $rolesResult->fetch_assoc()): ?>
                                    <option value="<?= $role['id'] ?>"><?= htmlspecialchars($role['role_name']) ?></option>
                                <?php endwhile; ?>
                            </select>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancel</button>
                        <button type="submit" name="update_user" class="btn btn-primary">Save Changes</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- JavaScript for Modal -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.2/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            // Open modal and populate fields for editing
            $('.editUserButton').click(function() {
                const id = $(this).data('id');
                const firstName = $(this).data('first-name');
                const lastName = $(this).data('last-name');
                const email = $(this).data('email');
                const phone = $(this).data('phone');
                const address = $(this).data('address');
                const username = $(this).data('username');
                const roleId = $(this).data('role-id');

                $('#editUserId').val(id);
                $('#editFirstName').val(firstName);
                $('#editLastName').val(lastName);
                $('#editEmail').val(email);
                $('#editPhone').val(phone);
                $('#editAddress').val(address);
                $('#editUsername').val(username);
                $('#editRoleId').val(roleId);

                $('#editUserModal').modal('show');
            });
        });
    </script>
</body>
</html>

<?php
$conn->close();
?>
